/*
 +---------------------------------------------------------------------+
 | csocket.h                                                           |
 | header file for csocket.cc                                          |
 |                                                                     |
 | Author:  Bob Pill, NCIS                                             |
 |          bobp@newcorridor.com                                       |
 |                                                                     |
 | Created: Sept 15, 1997                                              |
 |                                                                     |
 | Copyright (c) 1997 New Corridor Information Services.               |
 | All rights reserved.                                                |
 |                                                                     |
 |                                                                     |
 | THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR        |
 | IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED      |
 | WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR          |
 | PURPOSE.                                                            |
 |                                                                     |
 |---------------------------------------------------------------------|
 |  ***Revision-History***  Begin-Log                                  |
 |     Initial creation - (started at ver 2.0.1) Sept 15, 1997 (BP)    |
 |     Version 2.1.0 update Jan 01, 1998 (BP)                          |
 |     Version 2.1.1 update Feb 03, 1998 (BP)                          |
 |     Version 2.1.2 update May 17, 1998 (BP)                          |
 |     Version 2.1.3 update Aug 04, 1998 (BP)                          |
 |  ***Revision-History***  End-Log                                    |
 +---------------------------------------------------------------------+
*/

#ifndef __CSOCKET_H

#define __CSOCKET_H

#include <sys/socket.h>
#include <sys/un.h>

#define LISTEN_MAX_BACKLOG 5
#define MAX_BUFFERSIZE 1024

class CBuffer
{
public:

    CBuffer(void);
    ~CBuffer(void);
    char *GetBuffer(void) { return m_szBuffer ; }
    int Read(char *pszBuffer, int iSize, int &iBytes);
    int Write(char *pszFormat, ...);
    int WriteBuffer(char *pszBuffer, int iBytes);
    void ClearBuffer(void);
    int GetLength(void) {return m_iLength ; }
    int SetLength(int iLength);

private:

    void Init(void);

    int m_iLength;                    // length of data in buffer
    char m_szBuffer[MAX_BUFFERSIZE];  // data buffer
};



class CSocket
{
public:

    CSocket(const char *pszSocketName);
    CSocket(void);
    ~CSocket(void);

    const char *GetSocketName(void) { return m_szSocketPath ; }
    int Listen(void);
    int Connect(char *pszServerSocket);
    int Accept(void);
    int Read(int iBytesToRead);
    int Read(void);
    int Write(void);
    int Close(void);
    int Release(void);
    CBuffer* GetRcveBuffer(void) { return &m_bufRcve ; }
    CBuffer* GetSendBuffer(void) { return &m_bufSend ; }
    int GetListenSocket(void) { return m_fdSocketServer ; }
    int GetPartnerSocket(void) { return m_fdSocketNormal ; }

private:

    // methods

    void Init(void);

    // attribues
    int m_fdSocketNormal;                 // named stream socket descriptor - use for client/server exchange
    int m_fdSocketServer;                 // server socket - used by server to listen for connections
    int m_iLocalAddrLen;                  // local socket address length
    int m_iRemoteAddrLen;                 // local socket address length
    struct sockaddr_un m_saunLocal;       // local socket address
    struct sockaddr_un m_saunRemote;      // remote socket address
    char m_szSocketPath[MAX_PATHNAME];    // named stream socket path
    CBuffer m_bufSend;                    // send buffer
    CBuffer m_bufRcve;                    // receive buffer
};


#endif // __CSOCKET_H
