/*
 +---------------------------------------------------------------------+
 | ups.h                                                               |
 | header file for ups.cc                                              |
 |                                                                     |
 | Author:  Bob Pill, NCIS                                             |
 |          bobp@newcorridor.com                                       |
 |                                                                     |
 | Created: Sept 15, 1997                                              |
 |                                                                     |
 | Copyright (c) 1997 New Corridor Information Services.               |
 | All rights reserved.                                                |
 |                                                                     |
 |                                                                     |
 | THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR        |
 | IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED      |
 | WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR          |
 | PURPOSE.                                                            |
 |                                                                     |
 |---------------------------------------------------------------------|
 |  ***Revision-History***  Begin-Log                                  |
 |     Initial creation - (started at ver 2.0.1) Sept 15, 1997 (BP)    |
 |     Version 2.1.0 update Jan 01, 1998 (BP)                          |
 |     Version 2.1.1 update Feb 03, 1998 (BP)                          |
 |     Version 2.1.2 update May 17, 1998 (BP)                          |
 |     Version 2.1.3 update Aug 04, 1998 (BP)                          |
 |  ***Revision-History***  End-Log                                    |
 +---------------------------------------------------------------------+
*/


#ifndef __UPS_H

#define __UPS_H

#include "apcsmart.h"

#define MAX_UPS_RESPONSE 512

typedef struct UpsStatus
{
  BYTE byStandby;             // UPS running stand-by
  BYTE byPowerFailure;        // Input line power failue
  BYTE byBatteryLow;          // low battery
  BYTE byNotAvailable;        // status info not available
};


class Ups
{
public:
    
    Ups(const char *pszTTYName);
    ~Ups(void);

    int Init(void);
    void Command(BYTE byCommand);
    const UpsStatus& ReadStatus(void);
    const char* ReadString(BYTE byCommand);
    long ReadLong(BYTE byCommand);
    double ReadDouble(BYTE byCommand);
    char ReadEvent(void);
    int GetPortFD(void) { return m_fdPort ; }
    void Shutdown(void);

private:

    // methods

    void Reset(void);

    // attributes
    int m_fdPort;                         // serial port file descriptor
    int m_iDataLen;                       // length of data in response buffer
    struct termios m_oMode;               // default terminal line discipline
    struct termios m_upsMode;             // terminal line discipline for smartups device
    UpsStatus m_Status;                   // status descriptor block
    char m_szTTYName[MAX_PATHNAME];       // tty port device name
    char m_szResponse[MAX_UPS_RESPONSE];  // response buffer
};

#endif // __UPS_H

//---------------------------------------------------------------------
// end-of-file: ups.h                                                  
//---------------------------------------------------------------------
