/*
 +---------------------------------------------------------------------+
 | upsmonitor.h                                                        |
 | header file for upsmonitor.cc                                        |
 |                                                                     |
 | Author:  Bob Pill, NCIS                                             |
 |          bobp@newcorridor.com                                       |
 |                                                                     |
 | Created: Sept 15, 1997                                              |
 |                                                                     |
 | Copyright (c) 1997 New Corridor Information Services.               |
 | All rights reserved.                                                |
 |                                                                     |
 |                                                                     |
 | THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR        |
 | IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED      |
 | WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR          |
 | PURPOSE.                                                            |
 |                                                                     |
 |---------------------------------------------------------------------|
 |  ***Revision-History***  Begin-Log                                  |
 |     Initial creation - (started at ver 2.0.1) Sept 15, 1997 (BP)    |
 |     Version 2.1.0 update Jan 01, 1998 (BP)                          |
 |     Version 2.1.1 update Feb 03, 1998 (BP)                          |
 |     Version 2.1.2 update May 17, 1998 (BP)                          |
 |     Version 2.1.3 update Aug 04, 1998 (BP)                          |
 |  ***Revision-History***  End-Log                                    |
 +---------------------------------------------------------------------+
*/


#ifndef __UPSMONITOR_H

#define __UPSMONITOR_H

#include "csocket.h"
#include "ups.h"



//  UPS monitor states
                        
#define UPS_IDLE              0
#define UPS_POWER_FAIL_START  1
#define UPS_SHUTDOWN_PENDING  2
#define UPS_SHUTDOWN_FINAL    3


// monitor exit modes

#define UPSMONITOR_EXIT_NORMAL      0
#define UPSMONITOR_EXIT_SHUTDOWN 1000

// defaults

#define DEFAULT_RETRY_LIMIT     5  // power fail elapse timeout in minutes
#define MONITOR_SLEEP_INTERVAL 60


// UPS info

#define MAX_ARGSIZE 64

// UPSInfo function IDs
#define UPS_GET_STATUS 1


#define UPSInfoMsgFormatID 20758

typedef struct UpsInfoReq
{
   int iMsgFormatID;                 // message version of UpsInfo packet
   int iFunctionID;                  // request function ID
   char szArg1[MAX_ARGSIZE];         // argument 1
   char szArg2[MAX_ARGSIZE];         // argument 2
   char szArg3[MAX_ARGSIZE];         // argument 3
   char szArg4[MAX_ARGSIZE];         // argument 4
};

typedef struct UpsInfoResp
{
   int  iMsgFormatID;                // message version of UpsInfo packet
   int  iFunctionID;                 // function request ID
   int  iRetCode;                    // function return code
   char szUpsmondVersion[VRSN_MAX];  // upsmod daemon version
   char szModel[32];                 // APC SmartUPS model
   char szCopyRight[16];             // APC SmartUPS copyright
   char szMfgDate[16];               // APC SmartUPS manufacturing date
   char szSerial[32];                // APC SmartUPS serial number
   char szLocalID[32];               // APC SmartUPS local ID#
   char szFirmware[32];              // APC SmartUPS firmware version
   char szSmartUPSVersion[32];       // APC SmartUPS version
   char szBattReplaceDate[16];       // APC SmartUPS last battery replace date
   int iNomLine;                     // APC SmartUPS nominal line voltage
   int iNomBatt;                     // APC SmartUPS nominal battery voltage
   int iAvailable;                   // APC SmartUPS system ready
   int iStandby;                     // APC SmartUPS system in standby mode
   int iLine;                        // APC SmartUPS line voltage OK
   int iLowBatt;                     // APC SmartUPS battery is low
   double dLineVoltage;              // APC SmartUPS line voltage
   double dBattVoltage;              // APC SmartUPS battery voltage
   double dLoad;                     // APC SmartUPS system load
   double dBatteryLevel;             // APC SmartUPS battery level
};



class UpsMonitor
{
public:
    
    UpsMonitor(const char *pszTTYName, const char *pszSocketName, int iRetryLimit, const char *pszUpsmondVersion);
    ~UpsMonitor(void);

    int Init(void);
    void ShutdownUPS(void);
    void HandleUPSEvent(void);
    void HandleSocketEvent(void);
    int PostNormalResponse(void);
    int PostErrorResponse(int iRetcode, int iFucntionID);
    int ProcessRequest(UpsInfoReq *pReq);
    int Run(void);
    int GetSocket(void);

private:

    // methods

    // attributes
    Ups *m_pUps;                       // UPS interface object
    CSocket *m_pSocket;                // Monitor socket for IPC
    BOOL m_bClientConnected;           // client connected flag
    int m_iRetryLimit;                 // number of seconds before shutdown after power failure
    time_t m_tLastSelftest;            // last time self test was performed
    time_t m_tTimePowerFail;           // mark time power fails
    BOOL m_bBatteryLow;                // battery low flag
    int m_iState;                      // monitor state
    char m_szUpsmondVersion[VRSN_MAX]; // upsmond daemon version
};


#endif // __UPSMONITOR_H

//---------------------------------------------------------------------
// end-of-file: upsmonitor.h                                           
//---------------------------------------------------------------------
